Crate hashgrid

Crate hashgrid 

A 2D spatial-hash grid library

Type-Naming Convention

  • A: The coordinate type.
  • T: The hashable identifier type, defaults to u32.
  • S: The size of the hash table.

Modules

hash
mapper
range
table

Structs

Entry
Grid
Vector
A hash wrapper that only hashes the elements of the vector, but does not hash the length prefix (See Hasher::write_length_prefix).

Traits

IntoCellIter