pub struct Grid<T, A, M: Mapper<T, A>, const S_CELLS: usize = DEFAULT_S_CELLS, const S_MAPS: usize = DEFAULT_S_MAPS> { /* private fields */ }Implementations
Sourceimpl<T, A, M: Mapper<T, A>, const S_CELLS: usize, const S_MAPS: usize> Grid<T, A, M, S_CELLS, S_MAPS>
impl<T, A, M: Mapper<T, A>, const S_CELLS: usize, const S_MAPS: usize> Grid<T, A, M, S_CELLS, S_MAPS>
pub fn with_capacity(cell: usize, map: usize) -> Self
Sourceimpl<T, A, M: Mapper<T, A>, const S_CELLS: usize, const S_MAPS: usize> Grid<T, A, M, S_CELLS, S_MAPS>
impl<T, A, M: Mapper<T, A>, const S_CELLS: usize, const S_MAPS: usize> Grid<T, A, M, S_CELLS, S_MAPS>
Sourcepub unsafe fn inner_cells(
&mut self,
) -> &mut Table<Entry<T, S_CELLS>, BuildHasherDefault<MortonHasher>>
pub unsafe fn inner_cells( &mut self, ) -> &mut Table<Entry<T, S_CELLS>, BuildHasherDefault<MortonHasher>>
SAFETY
You MUST NOT modify the table structure if you are not sure what you are doing.
Sourcepub unsafe fn inner_maps(
&mut self,
) -> &mut Table<Entry<M::Entry, S_MAPS>, BuildHasherDefault<DummyHasher>>
pub unsafe fn inner_maps( &mut self, ) -> &mut Table<Entry<M::Entry, S_MAPS>, BuildHasherDefault<DummyHasher>>
SAFETY
You MUST NOT modify the table structure if you are not sure what you are doing.
Sourceimpl<T, A, M: Mapper<T, A>, const S_CELLS: usize, const S_MAPS: usize> Grid<T, A, M, S_CELLS, S_MAPS>
impl<T, A, M: Mapper<T, A>, const S_CELLS: usize, const S_MAPS: usize> Grid<T, A, M, S_CELLS, S_MAPS>
pub fn insert(&mut self, key: T, entity: M::Input)
pub fn remove(&mut self, key: &T) -> Option<()>
Sourcepub fn query(&self, range: impl IntoCellIter<A>) -> impl Iterator<Item = T>
pub fn query(&self, range: impl IntoCellIter<A>) -> impl Iterator<Item = T>
Query the grid for entities within a range.
This method does not check for duplicates caused by hash-collisions, or Mapper’s presentation (e.g. multi-cell item of [RangeMapper]).
pub fn clear(&mut self)